[cfe-commits] r38698 - /cfe/cfe/trunk/test/Preprocessor/macro_fn_lparen_scan.c

sabre at cs.uiuc.edu sabre at cs.uiuc.edu
Wed Jul 11 09:23:55 PDT 2007


Author: sabre
Date: Wed Jul 11 11:23:54 2007
New Revision: 38698

URL: http://llvm.org/viewvc/llvm-project?rev=38698&view=rev
Log:
new tests

Modified:
    cfe/cfe/trunk/test/Preprocessor/macro_fn_lparen_scan.c

Modified: cfe/cfe/trunk/test/Preprocessor/macro_fn_lparen_scan.c
URL: http://llvm.org/viewvc/llvm-project/cfe/cfe/trunk/test/Preprocessor/macro_fn_lparen_scan.c?rev=38698&r1=38697&r2=38698&view=diff

==============================================================================
--- cfe/cfe/trunk/test/Preprocessor/macro_fn_lparen_scan.c (original)
+++ cfe/cfe/trunk/test/Preprocessor/macro_fn_lparen_scan.c Wed Jul 11 11:23:54 2007
@@ -1,5 +1,7 @@
 // RUN: clang -E %s | grep 'noexp: foo y' &&
 // RUN: clang -E %s | grep 'expand: abc'
 
 #define A foo
 #define foo() abc
@@ -8,9 +10,18 @@
 // This should not expand to abc, because the foo macro isn't followed by (.
 noexp: X
 
-#undef X
 
 // This should expand to abc.
+#undef X
 #define X A ()
 expand: X
 
+
+// This should be 'foo nonexp'
+noexp2: A nonexp
+
+// This should expand
+expand2: A (
+)
+
+
@@ -1,5 +1,7 @@
 // RUN: clang -E %s | grep 'noexp: foo y' &&
-// RUN: clang -E %s | grep 'expand: abc'
+// RUN: clang -E %s | grep 'expand: abc' &&
+// RUN: clang -E %s | grep 'noexp2: foo nonexp' &&
+// RUN: clang -E %s | grep 'expand2: abc'
 
 #define A foo





More information about the cfe-commits mailing list